@@ -32,7 +32,7 @@ Implementation Notes
 
 """
 
-__version__ = "1.2.11"
+__version__ = "1.2.12"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AS7341.git"
 
 from time import sleep, monotonic
@@ -49,7 +49,9 @@ try:
     # Only needed for typing
     import busio  # pylint: disable=unused-import
 
-    TCallable = TypeVar("TCallable", bound=Callable[..., Any])
+    TCallable = TypeVar(  # pylint: disable=invalid-name
+        "TCallable", bound=Callable[..., Any]
+    )
 
 except ImportError:
     pass
